@@ -71,9 +71,7 @@ void MethodSwizzle(Class c, SEL originalSelector) {
 
       ParsePushPlugin* pluginInstance = [self getParsePluginInstance];
       [pluginInstance jsCallback:unwrappedInfo withAction:@"OPEN"];
-   } else{
-      NSLog(@"cold-start notification has no userInfo");
-   }
+  } //else no userInfo -> noop
 }
 
 - (BOOL)swizzled_application:(UIApplication*)application didFinishLaunchingWithOptions:(NSDictionary*)launchOptions
@@ -90,8 +88,9 @@ void MethodSwizzle(Class c, SEL originalSelector) {
       //
       ParsePushPlugin* pluginInstance = [self getParsePluginInstance];
 
-      NSString *appId     = [pluginInstance getConfigForKey:@"ParseAppId"];
-      NSString *serverUrl = [pluginInstance getConfigForKey:@"ParseServerUrl"];
+      NSString *appId      = [pluginInstance getConfigForKey:@"ParseAppId"];
+      NSString *serverUrl  = [pluginInstance getConfigForKey:@"ParseServerUrl"];
+      NSString *autoReg = [pluginInstance getConfigForKey:@"ParseAutoRegistration"];
 
       if(!appId.length){
          NSException* invalidSettingException = [NSException
@@ -124,12 +123,15 @@ void MethodSwizzle(Class c, SEL originalSelector) {
          }]];
       }
 
-
-
-      UIUserNotificationType userNotificationTypes = (UIUserNotificationTypeAlert | UIUserNotificationTypeBadge | UIUserNotificationTypeSound);
-      UIUserNotificationSettings *settings = [UIUserNotificationSettings settingsForTypes:userNotificationTypes categories:nil];
-      [application registerUserNotificationSettings:settings];
-      [application registerForRemoteNotifications];
+      if(!autoReg.length || [autoReg caseInsensitiveCompare:@"true"] || [application isRegisteredForRemoteNotifications]){
+          // if autoReg is true or nonexistent (defaults to true)
+          // or app already registered for PN, do/redo registration
+          //
+          // Note: redo registration because APNS device token can change and Apple
+          // suggests re-registering on each app start. registerForPN() is idempotent so
+          // no worries if it gets called multiple times.
+          [pluginInstance registerForPN];
+      }
 	}
 
    return isOk;
@@ -137,6 +139,7 @@ void MethodSwizzle(Class c, SEL originalSelector) {
 
 - (void)swizzled_application:(UIApplication *)application didRegisterForRemoteNotificationsWithDeviceToken:(NSData *)newDeviceToken
 {
+    NSLog(@"PN registration successful. Saving device token to installation");
     //
     // Call existing method in case it's already defined in main project's AppDelegate
     [self swizzled_application:application didRegisterForRemoteNotificationsWithDeviceToken:newDeviceToken];
@@ -146,7 +149,6 @@ void MethodSwizzle(Class c, SEL originalSelector) {
     [ParsePushPlugin saveDeviceTokenToInstallation:newDeviceToken];
 }
 
-
 - (void)swizzled_application:(UIApplication *)application didReceiveRemoteNotification:(NSDictionary *)userInfo
 {
    /*
