@@ -3,13 +3,13 @@
 
 @interface ParsePushPlugin: CDVPlugin
 
-@property (nonatomic, copy) NSString* callbackId;
-@property (nonatomic, retain) NSMutableArray* pnQueue;
+@property bool hasRegistered;
+@property (copy) NSString* callbackId;
+@property (retain) NSMutableArray* pnQueue;
 
 //
-// methods exposed to JS
-- (void)registerCallback: (CDVInvokedUrlCommand*)command;
-
+// methods exposed to JS as API
+- (void)register: (CDVInvokedUrlCommand *)command;
 - (void)getInstallationId: (CDVInvokedUrlCommand*)command;
 - (void)getInstallationObjectId: (CDVInvokedUrlCommand*)command;
 
@@ -17,9 +17,14 @@
 - (void)subscribe: (CDVInvokedUrlCommand *)command;
 - (void)unsubscribe: (CDVInvokedUrlCommand *)command;
 
+//
+// methods exposed to JS but not intended for users (not part of API)
+- (void)registerCallback: (CDVInvokedUrlCommand*)command;
+
 //
 // methods internal to plugin
 - (void)pluginInitialize;
+- (void)registerForPN;
 - (void)jsCallback: (NSDictionary*)userInfo withAction: (NSString*)pnAction;
 - (NSString *) getConfigForKey:(NSString *) key;
 + (void)saveDeviceTokenToInstallation: (NSData*)deviceToken;
